@@ -342,6 +342,8 @@ class Cursor(common.DBAPICursor):
             row = self._batch.pop()
         else:
             row = None
+            # reset row counter for next query execution
+            self.rows_count = 0
         return row
 
     # def fetchone(self):
